package net.knarcraft.placeholdersigns.util;

import org.bukkit.block.sign.Side;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;

/**
 * A helper class for generating tab-completions
 */
public final class TabCompleteHelper {

    private static final List<String> lineNumbers;
    private static final List<String> signSides;
    private static final List<String> updateDelays;

    static {
        lineNumbers = new ArrayList<>();
        for (int i = 1; i < 5; i++) {
            lineNumbers.add(String.valueOf(i));
        }

        signSides = new ArrayList<>();
        for (Side side : Side.values()) {
            signSides.add(side.name());
        }

        updateDelays = List.of("null", "1", "5", "10", "20", "40", "60", "80", "100");
    }

    private TabCompleteHelper() {

    }

    /**
     * Gets possible sign update delays
     *
     * @return <p>Possible sign update delays</p>
     */
    @NotNull
    public static List<String> getDelays() {
        return new ArrayList<>(updateDelays);
    }

    /**
     * Gets possible sign line numbers
     *
     * @return <p>Possible sign line numbers</p>
     */
    @NotNull
    public static List<String> getLineNumbers() {
        return new ArrayList<>(lineNumbers);
    }

    /**
     * Gets possible sign sides
     *
     * @return <p>Possible sign sides</p>
     */
    @NotNull
    public static List<String> getSignSides() {
        return new ArrayList<>(signSides);
    }

}
